/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats;

import java.text.MessageFormat;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.batch.core.step.tasklet.Tasklet;
import org.springframework.batch.repeat.ExitStatus;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.simple.SimpleJdbcDaoSupport;

/**
 * Task that analyzes tables to update index statistics to ensure decent aggregation performance
 * 
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public class AnalyzeTablesTask extends SimpleJdbcDaoSupport implements Tasklet {
    protected final Log logger = LogFactory.getLog(this.getClass());
    
    private String analyzeQueryTemplate;
    private List<String> tablesToAnalyze;
    
    public String getAnalyzeQueryTemplate() {
        return analyzeQueryTemplate;
    }
    /**
     * SQL template for the analyze calls. {@link MessageFormat} is used to substitue the table name into the query 
     */
    public void setAnalyzeQueryTemplate(String analyzeQueryTemplate) {
        this.analyzeQueryTemplate = analyzeQueryTemplate;
    }

    public List<String> getTablesToAnalyze() {
        return tablesToAnalyze;
    }
    /**
     * List of table names to use with the analyze query.
     */
    public void setTablesToAnalyze(List<String> tablesToAnalyze) {
        this.tablesToAnalyze = tablesToAnalyze;
    }

    /* (non-Javadoc)
     * @see org.springframework.batch.core.step.tasklet.Tasklet#execute()
     */
    public ExitStatus execute() throws Exception {
        if (this.tablesToAnalyze == null) {
            this.logger.info("No tables to analyze, returning");
        }
        
        final JdbcTemplate jdbcTemplate = this.getJdbcTemplate();
        for (final String table : this.tablesToAnalyze) {
            final String analyzeQuery = MessageFormat.format(this.analyzeQueryTemplate, table);
            
            if (this.logger.isDebugEnabled()) {
                this.logger.debug("Analyzing table '" + table + "' using query '" + analyzeQuery + "'");
            }
            
            final long startTime = System.currentTimeMillis();
            jdbcTemplate.execute(analyzeQuery);
            final long analyzeTime = System.currentTimeMillis() - startTime;
            this.logger.info("Analyzed table '" + table + "' in " + analyzeTime + "ms");
        }
        
        return ExitStatus.FINISHED;
    }
}
