/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats;

import net.sf.ehcache.Cache;
import net.sf.ehcache.CacheManager;
import net.sf.ehcache.Statistics;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.batch.core.step.tasklet.Tasklet;
import org.springframework.batch.repeat.ExitStatus;

/**
 * Simple tasklet that iterates over all Caches in a {@link CacheManager} and logs out their statistics at INFO level
 * 
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public class CacheStatsLoggingTask implements Tasklet {
    protected final Log logger = LogFactory.getLog(this.getClass());
    
    private CacheManager cacheManager;
    
    public CacheManager getCacheManager() {
        return this.cacheManager;
    }
    /**
     * The cache manager to print cache statistics from
     */
    public void setCacheManager(CacheManager cacheManager) {
        this.cacheManager = cacheManager;
    }

    /* (non-Javadoc)
     * @see org.springframework.batch.core.step.tasklet.Tasklet#execute()
     */
    public ExitStatus execute() throws Exception {
        if (this.logger.isInfoEnabled()) {
            final String[] cacheNames = this.cacheManager.getCacheNames();
            for (final String cacheName : cacheNames) {
                final Cache cache = this.cacheManager.getCache(cacheName);
                final Statistics statistics = cache.getStatistics();
                
                this.logger.info(statistics);
            }
        }
        
        return ExitStatus.FINISHED;
    }
}
