/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats;

import java.io.FileNotFoundException;

import org.jasig.portal.stats.shutdown.ShutdownHandler;
import org.springframework.context.support.ClassPathXmlApplicationContext;
import org.springframework.util.Log4jConfigurer;

/**
 * Utility class that loads the Spring app context and waits on the configured {@link ShutdownHandler}.
 * 
 * @author Eric Dalquist
 * @version $Revision: 46445 $
 */
public class StatsProcessorRunner {
    /**
     * @param args
     */
    public static void main(String[] args) throws Exception {
        final String log4jConfigFile = System.getProperty("log4j.configuration", "log4j.properties");
        try {
            Log4jConfigurer.initLogging("classpath:" + log4jConfigFile, 10000);
        }
        catch (FileNotFoundException fnfe) {
            Log4jConfigurer.initLogging("classpath:" + log4jConfigFile);
        }
        
        final String[] configLocations = new String[] {"/context/jobs/*.xml", "/context/*.xml"};
        final ClassPathXmlApplicationContext applicationContext = new ClassPathXmlApplicationContext(configLocations);
        
        final ShutdownHandler shutdownHandler = (ShutdownHandler)applicationContext.getBean("shutdownHandler", ShutdownHandler.class);
        shutdownHandler.waitForShutdown();
        
        applicationContext.destroy();
        Log4jConfigurer.shutdownLogging();
    }
}
