/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.PrintStream;
import java.net.InetAddress;
import java.net.Socket;
import java.util.Properties;

import org.apache.commons.io.IOUtils;

/**
 * Connects to the {@link org.jasig.portal.stats.shutdown.ShutdownHandler} and passes the first parameter passed on 
 * the command line. Any output from the handler is written to standard out.
 * 
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public class StatsProcessorShutdown {

    public static void main(String[] args) throws Exception {
        if (args.length != 1) {
            throw new IllegalArgumentException("Exactly 1 argment excpected, " + args.length + " recieved.");
        }
        
        final Properties shutdownProperties = new Properties();
        final InputStream shutdownPropertiesStream = StatsProcessorShutdown.class.getResourceAsStream("/shutdown.properties");
        try {
            shutdownProperties.load(shutdownPropertiesStream);
        }
        finally {
            IOUtils.closeQuietly(shutdownPropertiesStream);
        }
        
        
        final String host = shutdownProperties.getProperty("shutdownHost", "localhost");
        final int port = Integer.parseInt(shutdownProperties.getProperty("shutdownPort", "7456"));
        
        final String command = args[0];
        
        System.out.println("Calling processor on " + host + ":" + port + " with command: " + command);
        
        final InetAddress hostAddress = InetAddress.getByName(host);
        final Socket shutdownConnection = new Socket(hostAddress, port);
        try {
            final BufferedReader reader = new BufferedReader(new InputStreamReader(shutdownConnection.getInputStream()));
            final PrintStream writer = new PrintStream(shutdownConnection.getOutputStream());
            try {
                writer.println(command);
                writer.flush();

                while (true) {
                    final String line = reader.readLine();
                    if (line == null) {
                        break;
                    }
                    
                    System.out.println(line);
                }
            }
            finally {
                IOUtils.closeQuietly(reader);
                IOUtils.closeQuietly(writer);
            }
        }
        finally {
            try {
                shutdownConnection.close();
            }
            catch (IOException ioe) {
            }
        }
        
        
    }
}
