/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats.cache;

import java.io.Serializable;
import java.util.ArrayList;

/**
 * Assumes all objects in the tree are serializable, simply converts native arrays to ArrayLists recursing down the object graph as needed.
 * 
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public class CollectionsCacheKeyBuilder {
    public static Serializable generateCacheKey(Object obj) {
        if (obj == null) {
            return null;
        }
        
        if (obj.getClass().isArray()) {
            return generateCacheKey((Object[])obj);
        }
        
        return (Serializable)obj;
    }
    
    public static Serializable generateCacheKey(Object[] objs) {
        if (objs == null) {
            return null;
        }
        
        final ArrayList<Serializable> keyArray = new ArrayList<Serializable>(objs.length);
        for (final Object obj : objs) {
            final Serializable key = generateCacheKey(obj);
            keyArray.add(key);
        }
        
        return keyArray;
    }
}
