/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats.dao;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Collections;
import java.util.Map;

import org.jasig.portal.stats.SqlLoader;
import org.jasig.portal.stats.om.ChannelInfo;
import org.springframework.jdbc.core.simple.ParameterizedRowMapper;
import org.springframework.jdbc.core.simple.SimpleJdbcDaoSupport;
import org.springframework.jdbc.core.simple.SimpleJdbcTemplate;

/**
 * DAO that loads information from the portal database and then uses the configured {@link ChannelStatsKeyDao} to load
 * the stats key for the channel.
 * 
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public class ChannelInfoLoaderImpl extends SimpleJdbcDaoSupport implements ChannelInfoLoader {
    private final ParameterizedRowMapper<ChannelInfo> mapper;
    
    private final String chanIdParam;
    
    private final String channelInfoForDefIdQuery;
    
    
    private ChannelStatsKeyDao channelStatsKeyDao;
    
    public ChannelInfoLoaderImpl() {
        final SqlLoader sqlLoader = new SqlLoader("org/jasig/portal/stats/dao/ChannelInfoLoaderImplSql.xml", this.getClass().getClassLoader());
        this.chanIdParam = sqlLoader.getSql("chanIdParam");
        this.channelInfoForDefIdQuery = sqlLoader.getSql("channelInfoForDefId");
        
        this.mapper = new ChannelInfoRowMapper();
    }
    
    public ChannelStatsKeyDao getChannelStatsKeyDao() {
        return channelStatsKeyDao;
    }
    /**
     * The dao to use for stats DB specific channel information
     */
    public void setChannelStatsKeyDao(ChannelStatsKeyDao channelStatsKeyDao) {
        this.channelStatsKeyDao = channelStatsKeyDao;
    }

    /* (non-Javadoc)
     * @see org.jasig.portal.stats.mappers.ChannelInfoLoader#getChannelInfo(long)
     */
    public ChannelInfo getChannelInfo(long channelDefinitionId) {
        final SimpleJdbcTemplate simpleJdbcTemplate = this.getSimpleJdbcTemplate();
        
        final Map<String, Long> queryParams = Collections.singletonMap(this.chanIdParam, channelDefinitionId);
        final ChannelInfo channelInfo = simpleJdbcTemplate.queryForObject(this.channelInfoForDefIdQuery, this.mapper, queryParams);
        
        final long channelStatsKey = this.channelStatsKeyDao.getChannelStatsKey(channelInfo);
        channelInfo.setChannelStatsKey(channelStatsKey);
        
        if (this.logger.isDebugEnabled()) {
            this.logger.debug("Loaded ChannelInfo=" + channelInfo + " for channelDefinitionId=" + channelDefinitionId);
        }
        
        return channelInfo;
    }

    private static final class ChannelInfoRowMapper implements ParameterizedRowMapper<ChannelInfo> {

        /* (non-Javadoc)
         * @see org.springframework.jdbc.core.simple.ParameterizedRowMapper#mapRow(java.sql.ResultSet, int)
         */
        public ChannelInfo mapRow(ResultSet rs, int rowNum) throws SQLException {
            final ChannelInfo channelInfo = new ChannelInfo();
            
            final String fname = rs.getString("CHAN_FNAME");
            channelInfo.setFname(fname);
            
            final String name = rs.getString("CHAN_NAME");
            channelInfo.setName(name);
            
            final String title = rs.getString("CHAN_TITLE");
            channelInfo.setTitle(title);
            
            final String description = rs.getString("CHAN_DESC");
            channelInfo.setDescription(description);
            
            return channelInfo;
        }
    }
}
