/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats.dao;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jasig.portal.stats.dao.TabInfoDaoImpl.UserLayoutInfo;
import org.jasig.portal.stats.om.TabInfo;

/**
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public class TabInfoLoaderImpl implements TabInfoLoader {
    private static final String TRANSIENT_FOLDER_ID = "ft1";
    private static final Pattern DLM_NODE_REF = Pattern.compile("u([0-9]+)l([0-9]+)[n|s]([0-9]+)");
    private static final Pattern USER_NODE_REF = Pattern.compile("n([0-9]+)");
    
    protected final Log logger = LogFactory.getLog(this.getClass());
    
    private TabInfo transientTabInfo;
    private TabInfo unknownTabInfo;
    
    private String transientTabName = "No Tab Info Available";
    private String unknownTabName = "Unknown Tab";
    private TabInfoDao tabInfoDao;
    private TabStatsKeyDao tabStatsKeyDao;
    

    public TabStatsKeyDao getTabStatsKeyDao() {
        return tabStatsKeyDao;
    }
    /**
     * DAO to get stats specific TabInfo keys from 
     */
    public void setTabStatsKeyDao(TabStatsKeyDao tabStatsKeyDao) {
        this.tabStatsKeyDao = tabStatsKeyDao;
    }

    public TabInfoDao getTabInfoDao() {
        return tabInfoDao;
    }
    /**
     * DAO to look up portal user and tab information from
     */
    public void setTabInfoDao(TabInfoDao tabInfoDao) {
        this.tabInfoDao = tabInfoDao;
    }

    public String getTransientTabName() {
        return this.transientTabName;
    }
    /**
     * Name to use for tabs with a transient node id
     */
    public void setTransientTabName(String transientTabName) {
        this.transientTabName = transientTabName;
    }
    
    
    /* (non-Javadoc)
     * @see org.jasig.portal.stats.mappers.TabInfoLoader#getTabName(java.lang.String, int, java.lang.String)
     */
    public TabInfo getTabInfo(String username, int profileId, String layoutStructId) {
        if (TRANSIENT_FOLDER_ID.equals(layoutStructId)) {
            if (this.transientTabInfo == null) {
                final TabInfo tabInfo = new TabInfo();
                tabInfo.setName(this.transientTabName);
                
                final long tabStatsKey = this.tabStatsKeyDao.getTabStatsKey(tabInfo);
                tabInfo.setTabStatsKey(tabStatsKey);
                
                this.transientTabInfo = tabInfo;
            }
            
            return this.transientTabInfo;
        }
        
        
        final long userId;
        final long layoutId;
        final long nodeId;
        
        final Matcher dlmNodeRefMatcher = DLM_NODE_REF.matcher(layoutStructId);
        if (dlmNodeRefMatcher.matches()) {
            userId = Long.valueOf(dlmNodeRefMatcher.group(1));
            layoutId = Long.valueOf(dlmNodeRefMatcher.group(2));
            nodeId = Long.valueOf(dlmNodeRefMatcher.group(3));
            
            if (this.logger.isDebugEnabled()) {
                this.logger.debug("layoutStructId=" + layoutStructId + " is a DLM noderef");
            }
        }
        else {
            final Matcher userNodeRefMatcher = USER_NODE_REF.matcher(layoutStructId);
            if (userNodeRefMatcher.matches()) {
                final UserLayoutInfo userLayoutInfo = this.tabInfoDao.getUserLayoutInfo(username, profileId);
                userId = userLayoutInfo.userId;
                layoutId = userLayoutInfo.layoutId;
                nodeId = Long.valueOf(userNodeRefMatcher.group(1));
                
                if (this.logger.isDebugEnabled()) {
                    this.logger.debug("layoutStructId=" + layoutStructId + " is a user noderef");
                }
            }
            else {
                if (this.unknownTabInfo == null) {
                    final TabInfo tabInfo = new TabInfo();
                    tabInfo.setName(this.unknownTabName);
                    
                    final long tabStatsKey = this.tabStatsKeyDao.getTabStatsKey(tabInfo);
                    tabInfo.setTabStatsKey(tabStatsKey);
                    
                    this.unknownTabInfo = tabInfo;
                }

                this.logger.warn("Provided layoutStructId isn't in a valid format: '" + layoutStructId + "' for  username=" + username + " and profileId=" + profileId + ". returning '" + this.unknownTabInfo + "'");
                
                return this.unknownTabInfo;
            }
        }
    
        final TabInfo tabInfo = this.tabInfoDao.getTabInfo(userId, layoutId, nodeId);
        
        if (this.logger.isDebugEnabled()) {
            this.logger.debug("Found tab info '" + tabInfo + "' for userId=" + userId + " layoutId=" + layoutId + " nodeId=" + nodeId);
        }
        
        return tabInfo;
    }
}
