/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats.dao.aggr;

import java.util.Date;
import java.util.Map;
import java.util.Set;

import org.jasig.portal.stats.om.Interval;
import org.jasig.portal.stats.om.IntervalInfo;

/**
 * Stores scratch data and calculates aggregates for concurrent user calculations
 * 
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public interface ConcurrentUsersDao {
    /**
     * Saves the last seen event timestamps for each specified user name and group key. This data is stored in
     * a scratch table for use in later calculations when calling {@link #updateIntervals(Map, Set)}
     * 
     * @param Map of group keys, to user names to last seen event dates
     */
    public void saveLastEvents(Map<Integer, Map<String, Date>> lastEvents);

    /**
     * Updates aggregate calculations for the specified intervals and groups. The DAO may also clear out old scratch data
     * based on configuration and the intervals passed in.
     * 
     * @param intervals Map of intervals to concrete interval info, these are the intervals that need to have aggregates calculated
     * @param groupKeys Set of group keys seen in the specified intervals that need to have aggregates calculated
     */
    public void updateIntervals(Map<Interval, IntervalInfo> intervals, Set<Integer> groupKeys);
}
