/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats.dao.aggr;

import java.util.Date;
import java.util.Map;

import org.jasig.portal.stats.om.Interval;
import org.jasig.portal.stats.om.IntervalInfo;

/**
 * Stores scratch data and calculates aggregates for total and unique login calculations
 * 
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public interface LoginAggregationsDao {
    /**
     * Saves the last login timestamps for each specified user name and group key. This data is stored in
     * a scratch table for use in later calculations when calling {@link #updateIntervals(Map, Map)}
     * 
     * @param lastLogins Map of group keys to Map of userids & last login dates
     */
    public void saveLastLogins(Map<Integer, Map<String, Date>> lastLogins);

    /**
     * Updates aggregate calculations for the specified intervals and groups. The DAO may also clear out old scratch data
     * based on configuration and the intervals passed in.
     * 
     * @param intervals Intervals to update aggregates for
     * @param totalLogins Map of group keys to additional total logins for that group key 
     */
    public void updateIntervals(Map<Interval, IntervalInfo> intervals, Map<Integer, Integer> totalLogins);
}
