/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats.dao.aggr;

import java.util.List;
import java.util.Map;
import java.util.Set;

import org.jasig.portal.stats.om.Interval;
import org.jasig.portal.stats.om.IntervalInfo;
import org.jasig.portal.stats.om.LoginSummary;

/**
 * Stores scratch data and calculates aggregates for login frequency calculations
 * 
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public interface LoginFrequencyDao {
    /**
     * Saves the list of login summaries. This data is stored in a scratch table for use in later calculations when
     * calling {@link #updateIntervals(Map, Set)}
     * 
     * @param events List of login summaries to store
     */
    public void saveLogins(List<LoginSummary> events);
    
    /**
     * Updates aggregate calculations for the specified intervals and groups. The DAO may also clear out old scratch data
     * based on configuration and the intervals passed in.
     * 
     * @param intervals Map of intervals to concrete interval info, these are the intervals that need to have aggregates calculated
     * @param groupKeys Set of group keys seen in the specified intervals that need to have aggregates calculated
     */
    public void updateLoginFrequencies(Map<Interval, IntervalInfo> intervals, Set<Integer> groupKeys);
}
