/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats.dao.aggr;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.jasig.portal.stats.SqlLoader;
import org.jasig.portal.stats.om.ChannelData;
import org.jasig.portal.stats.om.Interval;
import org.jasig.portal.stats.om.IntervalInfo;
import org.springframework.transaction.annotation.Transactional;

/**
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public class PortletAggregateDaoImpl extends BatchingJdbcDaoSupport implements PortletAggregateDao {
    private final String dateKeyParam;
    private final String timeKeyParam;
    private final String intervalKeyParam;
    private final String timeSpanParam;
    private final String chanKeyParam;
    private final String groupKeyParam;
    
    private final String reqCountParam;
    private final String reqTotalParam;
    private final String reqMaxParam;
    private final String actCountParam;
    private final String actTotalParam;
    private final String actMaxParam;
    private final String targetCountParam;
    private final String cacheCountParam;
    
    //SQL to total unique logins and update the aggregate tables for by-group logins
    private final String upsertChannelRequests;
    
    public PortletAggregateDaoImpl() {
        final SqlLoader sqlLoader = new SqlLoader("org/jasig/portal/stats/dao/aggr/PortletAggregateDaoImplSql.xml", this.getClass().getClassLoader());
        
        this.dateKeyParam = sqlLoader.getSql("dateKeyParam");
        this.timeKeyParam = sqlLoader.getSql("timeKeyParam");
        this.intervalKeyParam = sqlLoader.getSql("intervalKeyParam");
        this.timeSpanParam = sqlLoader.getSql("timeSpanParam");
        this.chanKeyParam = sqlLoader.getSql("chanKeyParam");
        this.groupKeyParam = sqlLoader.getSql("groupKeyParam");
        
        this.reqCountParam = sqlLoader.getSql("reqCountParam");
        this.reqTotalParam = sqlLoader.getSql("reqTotalParam");
        this.reqMaxParam = sqlLoader.getSql("reqMaxParam");
        this.actCountParam = sqlLoader.getSql("actCountParam");
        this.actTotalParam = sqlLoader.getSql("actTotalParam");
        this.actMaxParam = sqlLoader.getSql("actMaxParam");
        this.targetCountParam = sqlLoader.getSql("targetCountParam");
        this.cacheCountParam = sqlLoader.getSql("cacheCountParam");
        
        this.upsertChannelRequests = sqlLoader.getSql("upsertChannelRequests");
    }
    
    
    /* (non-Javadoc)
     * @see org.jasig.portal.stats.dao.aggr.PortletAggregateDao#updateIntervals(java.util.Map, java.util.Map)
     */
    @Transactional
    public void updateIntervals(Map<Interval, IntervalInfo> intervals, Map<Integer, Map<Long, ChannelData>> channelDataMap) {
        final List<Map<String, Object>> batchParamters = new ArrayList<Map<String, Object>>(intervals.size() * channelDataMap.size() * 100);
        
        for (final Map.Entry<Interval, IntervalInfo> intervalEntry : intervals.entrySet()) {
            final Interval interval = intervalEntry.getKey();
            final IntervalInfo intervalInfo = intervalEntry.getValue();
        
            final long intervalKey = this.getIntervalKey(interval);
            final int startDateKey = intervalInfo.getStartDateKey();
            final int startTimeKey = intervalInfo.getStartTimeKey();
            final int timeSpan = intervalInfo.getTimeSpan();
            
            for (final Map.Entry<Integer, Map<Long, ChannelData>> channelDataMapEntry : channelDataMap.entrySet()) {
                final Integer statsGroupKey = channelDataMapEntry.getKey();
                final Map<Long, ChannelData> groupChannelData = channelDataMapEntry.getValue();
                
                for (final Map.Entry<Long, ChannelData> groupChannelDataEntry : groupChannelData.entrySet()) {
                    final Long statsChanKey = groupChannelDataEntry.getKey();
                    final ChannelData channelData = groupChannelDataEntry.getValue();
                    
                    final Map<String, Object> parameters = new HashMap<String, Object>();
                    parameters.put(this.dateKeyParam, startDateKey);
                    parameters.put(this.timeKeyParam, startTimeKey);
                    parameters.put(this.intervalKeyParam, intervalKey);
                    parameters.put(this.timeSpanParam, timeSpan);
                    parameters.put(this.groupKeyParam, statsGroupKey);
                    parameters.put(this.chanKeyParam, statsChanKey);
                    
                    parameters.put(this.reqCountParam, channelData.renderTimes.getCount());
                    parameters.put(this.reqTotalParam, channelData.renderTimes.getTotalTime());
                    parameters.put(this.reqMaxParam, channelData.renderTimes.getMaxTime());
                    
                    parameters.put(this.actCountParam, channelData.actionTimes.getCount());
                    parameters.put(this.actTotalParam, channelData.actionTimes.getTotalTime());
                    parameters.put(this.actMaxParam, channelData.actionTimes.getMaxTime());
                    
                    parameters.put(this.targetCountParam, channelData.targetedCount);
                    parameters.put(this.cacheCountParam, channelData.cachedCount);
                    
                    batchParamters.add(parameters);
                }
            }
        }

        if (batchParamters.size() > 0) {
            this.batchUpdate(this.upsertChannelRequests, batchParamters);
        }
        
        if (this.logger.isDebugEnabled()) {
            this.logger.debug("updateIntervals upserted " + batchParamters.size() + " rows.");
        }
    }
}
