/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats.dao.aggr;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.jasig.portal.stats.SqlLoader;
import org.jasig.portal.stats.om.CountAndTime;
import org.jasig.portal.stats.om.Interval;
import org.jasig.portal.stats.om.IntervalInfo;
import org.springframework.transaction.annotation.Transactional;

/**
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public class TabAggregateDaoImpl extends BatchingJdbcDaoSupport implements TabAggregateDao {
    private final String dateKeyParam;
    private final String timeKeyParam;
    private final String intervalKeyParam;
    private final String timeSpanParam;
    private final String tabKeyParam;
    private final String groupKeyParam;
    
    private final String reqCountParam;
    private final String reqTotalParam;
    private final String reqMaxParam;

    private final String upsertTabRequests;
    
    public TabAggregateDaoImpl() {
        final SqlLoader sqlLoader = new SqlLoader("org/jasig/portal/stats/dao/aggr/TabAggregateDaoImplSql.xml", this.getClass().getClassLoader());
        
        this.dateKeyParam = sqlLoader.getSql("dateKeyParam");
        this.timeKeyParam = sqlLoader.getSql("timeKeyParam");
        this.intervalKeyParam = sqlLoader.getSql("intervalKeyParam");
        this.timeSpanParam = sqlLoader.getSql("timeSpanParam");
        this.tabKeyParam = sqlLoader.getSql("tabKeyParam");
        this.groupKeyParam = sqlLoader.getSql("groupKeyParam");
        
        this.reqCountParam = sqlLoader.getSql("reqCountParam");
        this.reqTotalParam = sqlLoader.getSql("reqTotalParam");
        this.reqMaxParam = sqlLoader.getSql("reqMaxParam");
        
        this.upsertTabRequests = sqlLoader.getSql("upsertTabRequests");
    }


    /* (non-Javadoc)
     * @see org.jasig.portal.stats.dao.aggr.TabAggregateDao#updateIntervals(java.util.Map, java.util.Map)
     */
    @Transactional
    public void updateIntervals(Map<Interval, IntervalInfo> intervals, Map<Integer, Map<Long, CountAndTime>> tabDataMap) {
        final List<Map<String, Object>> batchParamters = new ArrayList<Map<String, Object>>(intervals.size() * tabDataMap.size() * 10);
        
        for (final Map.Entry<Interval, IntervalInfo> intervalEntry : intervals.entrySet()) {
            final Interval interval = intervalEntry.getKey();
            final IntervalInfo intervalInfo = intervalEntry.getValue();
        
            final long intervalKey = this.getIntervalKey(interval);
            final int startDateKey = intervalInfo.getStartDateKey();
            final int startTimeKey = intervalInfo.getStartTimeKey();
            final int timeSpan = intervalInfo.getTimeSpan();
            
            for (final Map.Entry<Integer, Map<Long, CountAndTime>> tabDataMapEntry : tabDataMap.entrySet()) {
                final Integer statsGroupKey = tabDataMapEntry.getKey();
                final Map<Long, CountAndTime> groupTabData = tabDataMapEntry.getValue();
                
                for (final Map.Entry<Long, CountAndTime> groupTabDataEntry : groupTabData.entrySet()) {
                    final Long statsChanKey = groupTabDataEntry.getKey();
                    final CountAndTime tabData = groupTabDataEntry.getValue();
                    
                    final Map<String, Object> parameters = new HashMap<String, Object>();
                    parameters.put(this.dateKeyParam, startDateKey);
                    parameters.put(this.timeKeyParam, startTimeKey);
                    parameters.put(this.intervalKeyParam, intervalKey);
                    parameters.put(this.timeSpanParam, timeSpan);
                    parameters.put(this.groupKeyParam, statsGroupKey);
                    parameters.put(this.tabKeyParam, statsChanKey);
                    
                    parameters.put(this.reqCountParam, tabData.getCount());
                    parameters.put(this.reqTotalParam, tabData.getTotalTime());
                    parameters.put(this.reqMaxParam, tabData.getMaxTime());
                    
                    batchParamters.add(parameters);
                }
            }
        }

        if (batchParamters.size() > 0) {
            this.batchUpdate(this.upsertTabRequests, batchParamters);
        }
        
        if (this.logger.isDebugEnabled()) {
            this.logger.debug("updateIntervals upserted " + batchParamters.size() + " rows.");
        }
    }
}
