/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats.events;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.apache.commons.lang.builder.ToStringStyle;

/**
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public class ChannelRenderedEvent extends ChannelEvent {
    private long time;
    private boolean cached;
    
    public ChannelRenderedEvent(long eventId) {
        super(eventId, EventType.CHANNEL_RENDERED);
    }
    
    
    /**
     * The time in milliseconds to render the channel
     */
    public long getTime() {
        return time;
    }
    public void setTime(long time) {
        this.time = time;
    }

    /**
     * If the channel was rendered from cache
     */
    public boolean isCached() {
        return cached;
    }
    public void setCached(boolean cached) {
        this.cached = cached;
    }

    /**
     * @see java.lang.Object#equals(Object)
     */
    @Override
    public boolean equals(Object object) {
        if (object == this) {
            return true;
        }
        if (!(object instanceof ChannelRenderedEvent)) {
            return false;
        }
        final ChannelRenderedEvent rhs = (ChannelRenderedEvent) object;
        return new EqualsBuilder()
            .appendSuper(super.equals(rhs))
            .append(this.time, rhs.time)
            .append(this.cached, rhs.cached)
            .isEquals();
    }

    /**
     * @see java.lang.Object#hashCode()
     */
    @Override
    public int hashCode() {
        return new HashCodeBuilder(2005163351, -206250959)
            .appendSuper(super.hashCode())
            .append(this.time)
            .append(this.cached)
            .toHashCode();
    }

    /**
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        return new ToStringBuilder(this, ToStringStyle.SHORT_PREFIX_STYLE)
            .appendSuper(super.toString())
            .append("time", this.time)
            .append("cached", this.cached)
            .toString();
    }
}
