/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats.events;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.apache.commons.lang.builder.ToStringStyle;
import org.jasig.portal.stats.om.TabInfo;

/**
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public class PageRenderedEvent extends PortalEvent {
    private TabInfo tabInfo;
    private long time;

    public PageRenderedEvent(long eventId) {
        super(eventId, EventType.PAGE_RENDER_TIME);
    }
    
    public TabInfo getTabInfo() {
        return tabInfo;
    }
    /**
     * The info for the layout folder rendered
     */
    public void setTabInfo(TabInfo tabInfo) {
        this.tabInfo = tabInfo;
    }
    
    /**
     * The time in milliseconds to render the page
     */
    public long getTime() {
        return time;
    }

    public void setTime(long time) {
        this.time = time;
    }

    /**
     * @see java.lang.Object#equals(Object)
     */
    @Override
    public boolean equals(Object object) {
        if (object == this) {
            return true;
        }
        if (!(object instanceof PageRenderedEvent)) {
            return false;
        }
        final PageRenderedEvent rhs = (PageRenderedEvent) object;
        return new EqualsBuilder()
            .appendSuper(super.equals(rhs))
            .append(this.tabInfo, rhs.tabInfo)
            .append(this.time, rhs.time)
            .isEquals();
    }

    /**
     * @see java.lang.Object#hashCode()
     */
    @Override
    public int hashCode() {
        return new HashCodeBuilder(2005163351, -206250959)
            .appendSuper(super.hashCode())
            .append(this.tabInfo)
            .append(this.time)
            .toHashCode();
    }

    /**
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        return new ToStringBuilder(this, ToStringStyle.SHORT_PREFIX_STYLE)
            .appendSuper(super.toString())
            .append("folderName", this.tabInfo)
            .append("time", this.time)
            .toString();
    }
}
