/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats.events;

import java.util.Date;
import java.util.Map;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.apache.commons.lang.builder.ToStringStyle;

/**
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public abstract class PortalEvent {
    private final long eventId;
    private final EventType type;
    private String userName;
    private Date activityDate;
    private Map<String, Integer> groups;
    
    public PortalEvent(long eventId, EventType type) {
        if (type == null) {
            throw new IllegalArgumentException("EventType cannot be null");
        }

        this.eventId = eventId;
        this.type = type;
    }
    
    public String getUserName() {
        return userName;
    }
    /**
     * @param userName the userName to set
     */
    public void setUserName(String userName) {
        this.userName = userName;
    }

    /**
     * The groups the user was in at login time
     */
    public Map<String, Integer> getGroups() {
        return groups;
    }
    public void setGroups(Map<String, Integer> groups) {
        this.groups = groups;
    }
    
    public Date getActivityDate() {
        return activityDate;
    }
    /**
     * @param activityDate the activityDate to set
     */
    public void setActivityDate(Date activityDate) {
        this.activityDate = activityDate;
    }
    
    public final EventType getType() {
        return this.type;
    }
    
    /**
     * @see java.lang.Object#equals(Object)
     */
    @Override
    public boolean equals(Object object) {
        if (object == this) {
            return true;
        }
        if (!(object instanceof PortalEvent)) {
            return false;
        }
        PortalEvent rhs = (PortalEvent) object;
        return new EqualsBuilder()
            .append(this.eventId, rhs.eventId)
            .append(this.type, rhs.type)
            .append(this.activityDate, rhs.activityDate)
            .append(this.userName, rhs.userName)
            .append(this.groups, rhs.groups)
            .isEquals();
    }
    /**
     * @see java.lang.Object#hashCode()
     */
    @Override
    public int hashCode() {
        return new HashCodeBuilder(-752878889, -1467351097)
            .append(this.eventId)
            .append(this.type)
            .append(this.activityDate)
            .append(this.userName)
            .append(this.groups)
            .toHashCode();
    }
    /**
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        return new ToStringBuilder(this, ToStringStyle.SHORT_PREFIX_STYLE)
        .append("eventId", this.eventId)
        .append("type", this.type)
        .append("activityDate", this.activityDate)
        .append("userName", this.userName)
        .append("groups", this.groups)
        .toString();
    }
}
