/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats.item.read;

import java.util.Collections;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

import org.jasig.portal.stats.SqlLoader;
import org.jasig.portal.stats.dao.StatsGroupsDao;
import org.springframework.jdbc.core.simple.ParameterizedRowMapper;
import org.springframework.jdbc.core.simple.ParameterizedSingleColumnRowMapper;
import org.springframework.jdbc.core.simple.SimpleJdbcDaoSupport;

/**
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public class SessionGroupsLoaderImpl extends SimpleJdbcDaoSupport implements SessionGroupsLoader {
    private final ParameterizedRowMapper<String> mapper;
    private final String sessionIdParam;
    private final String groupsForSessionIdQuery;
    
    private StatsGroupsDao statsGroupDao;
    private String allGroupsKey;
    
    public SessionGroupsLoaderImpl() {
        final SqlLoader sqlLoader = new SqlLoader("org/jasig/portal/stats/item/read/SessionGroupsLoaderImplSql.xml", this.getClass().getClassLoader());
        this.sessionIdParam = sqlLoader.getSql("sessionIdParam");
        this.groupsForSessionIdQuery = sqlLoader.getSql("groupsForSessionIdQuery");
        
        this.mapper = ParameterizedSingleColumnRowMapper.newInstance(String.class);
    }
    
    public StatsGroupsDao getStatsGroupDao() {
        return this.statsGroupDao;
    }
    /**
     * @param statsGroupDao the statsGroupDao to set
     */
    public void setStatsGroupDao(StatsGroupsDao statsGroupDao) {
        this.statsGroupDao = statsGroupDao;
    }

    public String getAllGroupsKey() {
        return this.allGroupsKey;
    }
    /**
     * Key to use for an 'all groups' group that is always present
     */
    public void setAllGroupsKey(String allGroupsKey) {
        this.allGroupsKey = allGroupsKey;
    }

    /* (non-Javadoc)
     * @see org.jasig.portal.stats.mappers.SessionGroupsLoader#getGroupKeys(long)
     */
    public Map<String, Integer> getGroupKeys(long sessionId) {
        final Map<?, ?> queryParams = Collections.singletonMap(this.sessionIdParam, sessionId);
        final List<String> portalGroupKeys = this.getSimpleJdbcTemplate().query(this.groupsForSessionIdQuery, this.mapper, queryParams);
        
        if (this.logger.isDebugEnabled()) {
            this.logger.debug("Found group keys " + portalGroupKeys + " for sessionId=" + sessionId);
        }
        
        if (portalGroupKeys == null) {
            return null;
        }
        
        final Map<String, Integer> groupKeys = this.statsGroupDao.getGroupKeys();

        final Map<String, Integer> filteredGroupKeys = this.filterGroups(portalGroupKeys, groupKeys);
        
        return filteredGroupKeys;
    }

    /**
     * Only return groups with mappings care about
     */
    protected Map<String, Integer> filterGroups(final List<String> portalGroupKeys, final Map<String, Integer> groupKeys) {
        final Map<String, Integer> filteredGroupKeys = new LinkedHashMap<String, Integer>();
        for (final String portalGroupKey : portalGroupKeys) {
            final Integer statsGroupKey = groupKeys.get(portalGroupKey);
            if (statsGroupKey != null) {
                filteredGroupKeys.put(portalGroupKey, statsGroupKey);
            }
        }
        
        if (this.allGroupsKey != null) {
            final Integer statsGroupKey = groupKeys.get(this.allGroupsKey);
            if (statsGroupKey != null) {
                filteredGroupKeys.put(this.allGroupsKey, statsGroupKey);
            }
        }
        
        return filteredGroupKeys;
    }
}
