/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats.item.read;

import java.util.concurrent.atomic.AtomicBoolean;

import org.jasig.portal.stats.shutdown.ShutdownListener;
import org.springframework.batch.core.StepExecution;
import org.springframework.batch.core.StepExecutionListener;
import org.springframework.batch.repeat.ExitStatus;

/**
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public class ShutdownAwareJdbcCursorItemReader extends JdbcCursorItemReader implements StepExecutionListener, ShutdownListener {
    private final AtomicBoolean executing = new AtomicBoolean(false);
    private final AtomicBoolean shutdown = new AtomicBoolean(false);
    
    
    /* (non-Javadoc)
     * @see org.jasig.portal.stats.item.read.JdbcCursorItemReader#doRead()
     */
    @Override
    protected Object doRead() throws Exception {
        if (this.shutdown.get()) {
            return null;
        }
        
        return super.doRead();
    }

    /* (non-Javadoc)
     * @see org.jasig.portal.stats.ShutdownListener#shutdown()
     */
    public void shutdown() {
        boolean wasShutdown = this.shutdown.getAndSet(true);
        if (!wasShutdown && this.executing.get()) {
            synchronized (this.shutdown) {
                try {
                    this.shutdown.wait();
                }
                catch (InterruptedException e) {
                    this.logger.warn("Interrupted while waiting for shutdown notification");
                }
            }
        }
    }
    
    /* (non-Javadoc)
     * @see org.springframework.batch.core.StepExecutionListener#beforeStep(org.springframework.batch.core.StepExecution)
     */
    public void beforeStep(StepExecution stepExecution) {
        this.executing.set(true);
    }
    
    /* (non-Javadoc)
     * @see org.springframework.batch.core.StepExecutionListener#afterStep(org.springframework.batch.core.StepExecution)
     */
    public ExitStatus afterStep(StepExecution stepExecution) {
        this.signalReaderEnd();
        return null;
    }
    /* (non-Javadoc)
     * @see org.springframework.batch.core.StepExecutionListener#onErrorInStep(org.springframework.batch.core.StepExecution, java.lang.Throwable)
     */
    public ExitStatus onErrorInStep(StepExecution stepExecution, Throwable e) {
        this.signalReaderEnd();
        return null;
    }
    
    protected void signalReaderEnd() {
        this.executing.set(false);
        
        if (this.shutdown.get()) {
            synchronized (this.shutdown) {
                this.shutdown.notifyAll();
            }
        }
    }
}
