/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats.item.write;

import java.util.EnumSet;
import java.util.Set;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jasig.portal.stats.events.EventType;
import org.jasig.portal.stats.events.PortalEvent;
import org.jasig.portal.stats.om.Interval;

/**
 * Base class for an interval aware event writer, handles filtering for supported event types and intervals
 * 
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public abstract class BaseIntervalAwareItemWriter<T extends PortalEvent> implements IntervalAwareItemWriter<T> {
    protected final Log logger = LogFactory.getLog(this.getClass());
    
    private Set<EventType> supportedEvents;
    private Set<Interval> supportedIntervals;
    
    public final Set<EventType> getSupportedEvents() {
        return supportedEvents;
    }
    /**
     * The Set of classes supported by this writer, if not set all item types will be supported
     */
    public final void setSupportedEvents(Set<EventType> supportedItems) {
        if (supportedItems == null) {
            this.supportedEvents = null;
        }
        else {
            this.supportedEvents = EnumSet.copyOf(supportedItems);
        }
    }

    public final Set<Interval> getSupportedIntervals() {
        return supportedIntervals;
    }
    /**
     * The Set of intervals handled by this writer, if not set all intervals are handled. 
     */
    public final void setSupportedIntervals(Set<Interval> supportedIntervals) {
        if (supportedIntervals == null) {
            this.supportedIntervals = null;
        }
        else {
            this.supportedIntervals = EnumSet.copyOf(supportedIntervals);
        }
    }
    

    /* (non-Javadoc)
     * @see org.jasig.portal.stats.item.write.IntervalAwareItemWriter#handles(org.jasig.portal.stats.Interval)
     */
    public final boolean handles(Interval interval) {
        return this.supportedIntervals == null || this.supportedIntervals.contains(interval);
    }

    /* (non-Javadoc)
     * @see org.jasig.portal.stats.item.write.IntervalAwareItemWriter#supports(java.lang.Class)
     */
    public final boolean supports(EventType eventType) {
        return this.supportedEvents == null || this.supportedEvents.contains(eventType);
    }
}
