/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats.item.write;

import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jasig.portal.stats.events.EventType;
import org.jasig.portal.stats.events.PortalEvent;
import org.jasig.portal.stats.om.Interval;
import org.jasig.portal.stats.om.IntervalInfo;
import org.springframework.batch.item.ClearFailedException;
import org.springframework.batch.item.FlushFailedException;

/**
 * Logs at trace level calls to all methods with arguments
 * 
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public class LoggingIntervalAwareItemWriter implements IntervalAwareItemWriter<PortalEvent> {
    protected final Log logger = LogFactory.getLog(this.getClass());

    
    /* (non-Javadoc)
     * @see org.jasig.portal.stats.item.write.IntervalAwareItemWriter#doClear()
     */
    public void doClear() throws ClearFailedException {
        if (this.logger.isTraceEnabled()) {
            this.logger.trace("doClear()");
        }
    }

    /* (non-Javadoc)
     * @see org.jasig.portal.stats.item.write.IntervalAwareItemWriter#doFlush(java.util.Map)
     */
    public void doFlush(Map<Interval, IntervalInfo> intervalInfo) throws FlushFailedException {
        if (this.logger.isTraceEnabled()) {
            this.logger.trace("doFlush(" + intervalInfo + ")");
        }
    }

    /* (non-Javadoc)
     * @see org.jasig.portal.stats.item.IntervalAwareItemWriter#doWrite(java.lang.Object)
     */
    public void doWrite(PortalEvent item) throws Exception {
        if (this.logger.isInfoEnabled()) {
            this.logger.info("doWrite(" + item + ")");
        }
    }

    /* (non-Javadoc)
     * @see org.jasig.portal.stats.item.write.IntervalAwareItemWriter#handleIntervalBoundry(org.jasig.portal.stats.Interval, java.util.Map)
     */
    public void handleIntervalBoundry(Interval interval, Map<Interval, IntervalInfo> intervals) {
        if (this.logger.isInfoEnabled()) {
            this.logger.info("handleIntervalBoundry(" + interval + ", " + intervals + ")");
        }
    }

    /* (non-Javadoc)
     * @see org.jasig.portal.stats.item.write.IntervalAwareItemWriter#supports(org.jasig.portal.stats.events.EventType)
     */
    public boolean supports(EventType eventType) {
        return true;
    }

    /* (non-Javadoc)
     * @see org.jasig.portal.stats.item.write.IntervalAwareItemWriter#handles(org.jasig.portal.stats.Interval)
     */
    public boolean handles(Interval interval) {
        return true;
    }
}
