/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats.item.write;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.batch.item.ClearFailedException;
import org.springframework.batch.item.FlushFailedException;
import org.springframework.batch.item.ItemWriter;

/**
 * Logs at trace level calls to all methods with arguments
 * 
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public class LoggingItemWriter implements ItemWriter {
    protected final Log logger = LogFactory.getLog(this.getClass());

    /* (non-Javadoc)
     * @see org.springframework.batch.item.ItemWriter#clear()
     */
    public void clear() throws ClearFailedException {
        if (this.logger.isTraceEnabled()) {
            this.logger.trace("clear()");
        }
    }

    /* (non-Javadoc)
     * @see org.springframework.batch.item.ItemWriter#flush()
     */
    public void flush() throws FlushFailedException {
        if (this.logger.isTraceEnabled()) {
            this.logger.trace("flush()");
        }
    }

    /* (non-Javadoc)
     * @see org.springframework.batch.item.ItemWriter#write(java.lang.Object)
     */
    public void write(Object item) throws Exception {
        this.logger.info(item);
    }

}
