/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats.item.write;

import java.util.Date;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jasig.portal.stats.events.EventType;
import org.jasig.portal.stats.events.PortalEvent;
import org.jasig.portal.stats.om.Interval;
import org.jasig.portal.stats.om.IntervalInfo;
import org.springframework.batch.item.ClearFailedException;
import org.springframework.batch.item.FlushFailedException;

/**
 * Tracks the first seen event date, the last, the number of events seens and intervals seen. Logs all of this
 * information on flush or clear 
 * 
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public class SummaryLoggingIntervalAwareItemWriter implements IntervalAwareItemWriter<PortalEvent> {
    protected final Log logger = LogFactory.getLog(this.getClass());
    
    private Date firstEventDate = null;
    private Date lastEventDate = null;
    private long eventCount = 0;
    private long intervalCount = 0;

    
    /* (non-Javadoc)
     * @see org.jasig.portal.stats.item.write.IntervalAwareItemWriter#doClear()
     */
    public void doClear() throws ClearFailedException {
        this.logger.info("doClear: eventCount=" + eventCount + ", intervalCount=" + intervalCount + ", firstEventDate=" + firstEventDate + ", lastEventDate=" + lastEventDate);
        clearTrackingData();
    }

    /* (non-Javadoc)
     * @see org.jasig.portal.stats.item.write.IntervalAwareItemWriter#doFlush(java.util.Map)
     */
    public void doFlush(Map<Interval, IntervalInfo> intervalInfo) throws FlushFailedException {
        this.logger.info("doFlush: eventCount=" + eventCount + ", intervalCount=" + intervalCount + ", firstEventDate=" + firstEventDate + ", lastEventDate=" + lastEventDate);
        clearTrackingData();
    }

    /* (non-Javadoc)
     * @see org.jasig.portal.stats.item.IntervalAwareItemWriter#doWrite(java.lang.Object)
     */
    public void doWrite(PortalEvent item) throws Exception {
        this.lastEventDate = item.getActivityDate();
        if (this.firstEventDate == null) {
            this.firstEventDate = this.lastEventDate;
        }
        
        this.eventCount++;
    }

    /* (non-Javadoc)
     * @see org.jasig.portal.stats.item.write.IntervalAwareItemWriter#handleIntervalBoundry(org.jasig.portal.stats.Interval, java.util.Map)
     */
    public void handleIntervalBoundry(Interval interval, Map<Interval, IntervalInfo> intervals) {
        this.intervalCount++;
    }

    /* (non-Javadoc)
     * @see org.jasig.portal.stats.item.write.IntervalAwareItemWriter#supports(org.jasig.portal.stats.events.EventType)
     */
    public boolean supports(EventType eventType) {
        return true;
    }

    /* (non-Javadoc)
     * @see org.jasig.portal.stats.item.write.IntervalAwareItemWriter#handles(org.jasig.portal.stats.Interval)
     */
    public boolean handles(Interval interval) {
        return true;
    }

    private void clearTrackingData() {
        this.firstEventDate = null;
        this.lastEventDate = null;
        this.eventCount = 0;
        this.intervalCount = 0;
    }
}
