/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats.om;

import java.io.Serializable;

import org.apache.commons.lang.builder.HashCodeBuilder;
import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.apache.commons.lang.builder.ToStringStyle;

/**
 * Represents a channel for stats aggregation purposes, the channelStatsKey should be used as a foriegn key by
 * any stats that need to reference a particular channel
 * 
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public class ChannelInfo implements Serializable {
    private static final long serialVersionUID = 1L;

    private long channelStatsKey;
    private String fname;
    private String name;
    private String title;
    private String description;
    

    /**
     * @return the channelStatsKey
     */
    public long getChannelStatsKey() {
        return channelStatsKey;
    }
    /**
     * @param channelStatsKey the channelStatsKey to set
     */
    public void setChannelStatsKey(long channelStatsKey) {
        this.channelStatsKey = channelStatsKey;
    }
    /**
     * @return the fname
     */
    public String getFname() {
        return fname;
    }
    /**
     * @param fname the fname to set
     */
    public void setFname(String fname) {
        this.fname = fname;
    }
    /**
     * @return the name
     */
    public String getName() {
        return name;
    }
    /**
     * @param name the name to set
     */
    public void setName(String name) {
        this.name = name;
    }
    /**
     * @return the title
     */
    public String getTitle() {
        return title;
    }
    /**
     * @param title the title to set
     */
    public void setTitle(String title) {
        this.title = title;
    }
    /**
     * @return the description
     */
    public String getDescription() {
        return description;
    }
    /**
     * @param description the description to set
     */
    public void setDescription(String description) {
        this.description = description;
    }
    
    /**
     * @see java.lang.Object#hashCode()
     */
    @Override
    public int hashCode() {
        return new HashCodeBuilder(1111058281, -1011678045)
            .append(this.channelStatsKey)
            .append(this.title)
            .append(this.description)
            .append(this.name)
            .append(this.fname)
            .toHashCode();
    }
    /**
     * @see java.lang.Object#equals(Object)
     */
    @Override
    public boolean equals(Object object) {
        if (object == this) {
            return true;
        }
        if (!(object instanceof ChannelInfo)) {
            return false;
        }
        ChannelInfo rhs = (ChannelInfo) object;
        return new EqualsBuilder()
            .append(this.channelStatsKey, rhs.channelStatsKey)
            .append(this.title, rhs.title)
            .append(this.description, rhs.description)
            .append(this.name, rhs.name)
            .append(this.fname, rhs.fname)
            .isEquals();
    }
    /**
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        return new ToStringBuilder(this, ToStringStyle.SHORT_PREFIX_STYLE)
            .append("channelStatsKey", this.channelStatsKey)
            .append("fname", this.fname)
            .append("name", this.name)
            .append("title", this.title)
            .append("description", this.description)
            .toString();
    }
}
