/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.stats.quartz;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.quartz.JobExecutionContext;
import org.springframework.batch.core.Job;
import org.springframework.batch.core.JobParameters;
import org.springframework.batch.core.launch.JobLauncher;
import org.springframework.batch.core.repository.JobExecutionAlreadyRunningException;
import org.springframework.batch.core.repository.JobInstanceAlreadyCompleteException;
import org.springframework.batch.core.repository.JobRestartException;
import org.springframework.scheduling.quartz.QuartzJobBean;

/**
 * Locates, sets up and executes a Job
 * 
 * @author Eric Dalquist
 * @version $Revision: 46014 $
 */
public class JobLauncherDetails extends QuartzJobBean {
    protected final Log logger = LogFactory.getLog(this.getClass());

    private Job job;
    private JobLauncher jobLauncher;
    private JobParametersProvider jobParametersProvider;

    /**
     * Public setter for the {@link JobLauncher}.
     * @param jobLauncher the {@link JobLauncher} to set
     */
    public void setJobLauncher(JobLauncher jobLauncher) {
        this.jobLauncher = jobLauncher;
    }
    
    /**
     * @param jobParametersProvider the jobParametersProvider to set
     */
    public void setJobParametersProvider(JobParametersProvider jobParametersProvider) {
        this.jobParametersProvider = jobParametersProvider;
    }

    /**
     * The job to run
     */
    public void setJob(Job job) {
        this.job = job;
    }

    /* (non-Javadoc)
     * @see org.springframework.scheduling.quartz.QuartzJobBean#executeInternal(org.quartz.JobExecutionContext)
     */
    @Override
    protected void executeInternal(JobExecutionContext context) {
        //Get the JobParameters
        final JobParameters jobParameters;
        if (this.jobParametersProvider != null) {
            jobParameters = this.jobParametersProvider.getJobParameters(job);
        }
        else {
            jobParameters = new JobParameters();
        }
        
        //Run the job
        try {
            this.logger.info("Quartz trigger firing with Spring Batch jobName=" + this.job.getName());
            this.jobLauncher.run(this.job, jobParameters);
        }
        catch (JobExecutionAlreadyRunningException e) {
            this.logger.info("Job '" + this.job.getName() + "' instance is already running: " + e.getMessage());
        }
        catch (JobRestartException e) {
            this.logger.error("Job '" + this.job.getName() + "' failed to restart.", e);
        }
        catch (JobInstanceAlreadyCompleteException e) {
            this.logger.warn("Job '" + this.job.getName() + "' instance is already complete: " + e.getMessage());
        }
    }

}
